# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional

try:
    from pydantic.v1 import BaseModel, Field, StrictInt, StrictStr, validator
except ImportError:
    from pydantic import BaseModel, Field, StrictInt, StrictStr, validator

from mozart_api.models.software_update_state import SoftwareUpdateState


class SoftwareUpdateStatus(BaseModel):
    """
    SoftwareUpdateStatus
    """

    available_update: Optional[StrictStr] = Field(default=None, alias="availableUpdate")
    last_check: Optional[datetime] = Field(default=None, alias="lastCheck")
    last_update: Optional[datetime] = Field(default=None, alias="lastUpdate")
    software_version: StrictStr = Field(default=..., alias="softwareVersion")
    state: SoftwareUpdateState = Field(...)
    update_progress: Optional[StrictInt] = Field(default=None, alias="updateProgress")
    update_type: Optional[StrictStr] = Field(default=None, alias="updateType")
    __properties = [
        "availableUpdate",
        "lastCheck",
        "lastUpdate",
        "softwareVersion",
        "state",
        "updateProgress",
        "updateType",
    ]

    @validator("update_type")
    def update_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ("none", "normal", "critical", "forced"):
            raise ValueError(
                "must be one of enum values ('none', 'normal', 'critical', 'forced')"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SoftwareUpdateStatus:
        """Create an instance of SoftwareUpdateStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of state
        if self.state:
            _dict["state"] = self.state.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SoftwareUpdateStatus:
        """Create an instance of SoftwareUpdateStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SoftwareUpdateStatus.parse_obj(obj)

        _obj = SoftwareUpdateStatus.parse_obj(
            {
                "available_update": obj.get("availableUpdate"),
                "last_check": obj.get("lastCheck"),
                "last_update": obj.get("lastUpdate"),
                "software_version": obj.get("softwareVersion"),
                "state": (
                    SoftwareUpdateState.from_dict(obj.get("state"))
                    if obj.get("state") is not None
                    else None
                ),
                "update_progress": obj.get("updateProgress"),
                "update_type": obj.get("updateType"),
            }
        )
        return _obj
