# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


try:
    from pydantic.v1 import BaseModel, Field, StrictInt
except ImportError:
    from pydantic import BaseModel, Field, StrictInt


class SpeakerGroupMemberLocation(BaseModel):
    """
    Coordinates of the speaker position in cm. Location is only relevant when the group is based on the automatic role assignment of advanced room compensation. The location is relative to the external microphone used during advanced room compensation measurements:   x=0, y=0, z=0: The location of the external microphone used during measurement.   x<0: To the left of the external microphone.   x>0: To the right of the external microphone.   y<0: Behind the external microphone.   y>0: In front of the external microphone.   z<0: Above the external microphone (may not be reliable).   z>0: Below the external microphone (may not be reliable).   # noqa: E501
    """

    x: StrictInt = Field(...)
    y: StrictInt = Field(...)
    z: StrictInt = Field(...)
    __properties = ["x", "y", "z"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SpeakerGroupMemberLocation:
        """Create an instance of SpeakerGroupMemberLocation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SpeakerGroupMemberLocation:
        """Create an instance of SpeakerGroupMemberLocation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SpeakerGroupMemberLocation.parse_obj(obj)

        _obj = SpeakerGroupMemberLocation.parse_obj(
            {"x": obj.get("x"), "y": obj.get("y"), "z": obj.get("z")}
        )
        return _obj
